package com.ruoyi.asset.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.asset.domain.TbAssetStatusRecord;

/**
 * 资产设备状态记录Service接口
 * 
 * @author 原动力
 * @date 2023-03-27
 */
public interface ITbAssetStatusRecordService extends IService<TbAssetStatusRecord>
{
    /**
     * 查询资产设备状态记录
     * 
     * @param id 资产设备状态记录主键
     * @return 资产设备状态记录
     */
    public TbAssetStatusRecord selectTbAssetStatusRecordById(Long id);

    /**
     * 查询资产设备状态记录列表
     * 
     * @param tbAssetStatusRecord 资产设备状态记录
     * @return 资产设备状态记录集合
     */
    public List<TbAssetStatusRecord> selectTbAssetStatusRecordList(TbAssetStatusRecord tbAssetStatusRecord);

    /**
     * 新增资产设备状态记录
     * 
     * @param tbAssetStatusRecord 资产设备状态记录
     * @return 结果
     */
    public int insertTbAssetStatusRecord(TbAssetStatusRecord tbAssetStatusRecord);

    /**
     * 修改资产设备状态记录
     * 
     * @param tbAssetStatusRecord 资产设备状态记录
     * @return 结果
     */
    public int updateTbAssetStatusRecord(TbAssetStatusRecord tbAssetStatusRecord);

    /**
     * 批量删除资产设备状态记录
     * 
     * @param ids 需要删除的资产设备状态记录主键集合
     * @return 结果
     */
    public int deleteTbAssetStatusRecordByIds(Long[] ids);

    /**
     * 删除资产设备状态记录信息
     * 
     * @param id 资产设备状态记录主键
     * @return 结果
     */
    public int deleteTbAssetStatusRecordById(Long id);
}
